@@ -139,6 +139,7 @@ class SlackInput(InputChannel):
             credentials.get("errors_ignore_retry", None),
             credentials.get("use_threads", False),
             credentials.get("slack_signing_secret", ""),
+            credentials.get("conversation_granularity", "sender"),
         )
 
     def __init__(
@@ -151,6 +152,7 @@ class SlackInput(InputChannel):
         errors_ignore_retry: Optional[List[Text]] = None,
         use_threads: Optional[bool] = False,
         slack_signing_secret: Text = "",
+        conversation_granularity: Optional[Text] = "sender",
     ) -> None:
         """Create a Slack input channel.
 
@@ -182,7 +184,10 @@ class SlackInput(InputChannel):
             slack_signing_secret: Slack creates a unique string for your app and
                 shares it with you. This allows us to verify requests from Slack
                 with confidence by verifying signatures using your signing secret.
-
+            conversation_granularity: conversation granularity for slack conversations.
+                sender allows 1 conversation per user (across channels)
+                channel allows 1 conversation per user per channel
+                thread allows 1 conversation per user per thread
         """
         self.slack_token = slack_token
         self.slack_channel = slack_channel
@@ -192,6 +197,7 @@ class SlackInput(InputChannel):
         self.retry_num_header = slack_retry_number_header
         self.use_threads = use_threads
         self.slack_signing_secret = slack_signing_secret
+        self.conversation_granularity = conversation_granularity
 
         self._validate_credentials()
 
@@ -505,6 +511,11 @@ class SlackInput(InputChannel):
                 user_message = event.get("text", "")
                 sender_id = event.get("user", "")
                 metadata = self.get_metadata(request)
+                channel_id = metadata.get("out_channel")
+                thread_id = metadata.get("thread_id")
+                conversation_id = self._get_conversation_id(
+                    sender_id, channel_id, thread_id
+                )
 
                 if "challenge" in output:
                     return response.json(output.get("challenge"))
@@ -527,7 +538,7 @@ class SlackInput(InputChannel):
                     request,
                     on_new_message,
                     text=self._sanitize_user_message(user_message, metadata["users"]),
-                    sender_id=sender_id,
+                    sender_id=conversation_id,
                     metadata=metadata,
                 )
             elif content_type == "application/x-www-form-urlencoded":
@@ -540,8 +551,13 @@ class SlackInput(InputChannel):
                     text = self._get_interactive_response(payload["actions"][0])
                     if text is not None:
                         metadata = self.get_metadata(request)
+                        channel_id = metadata.get("out_channel")
+                        thread_id = metadata.get("thread_id")
+                        conversation_id = self._get_conversation_id(
+                            sender_id, channel_id, thread_id
+                        )
                         return await self.process_message(
-                            request, on_new_message, text, sender_id, metadata
+                            request, on_new_message, text, conversation_id, metadata
                         )
                     if payload["actions"][0]["type"] == "button":
                         # link buttons don't have "value", don't send their clicks to
@@ -556,6 +572,24 @@ class SlackInput(InputChannel):
 
         return slack_webhook
 
+    def _get_conversation_id(
+        self,
+        sender_id: Optional[Text],
+        channel_id: Optional[Text],
+        thread_id: Optional[Text],
+    ) -> Optional[Text]:
+        conversation_id = sender_id
+        if self.conversation_granularity == "channel" and sender_id and channel_id:
+            conversation_id = sender_id + "_" + channel_id
+        if (
+            self.conversation_granularity == "thread"
+            and sender_id
+            and channel_id
+            and thread_id
+        ):
+            conversation_id = sender_id + "_" + channel_id + "_" + thread_id
+        return conversation_id
+
     def _is_supported_channel(self, slack_event: Dict, metadata: Dict) -> bool:
         return (
             self._is_direct_message(slack_event)
